@@ -91,7 +91,7 @@ enum {
 	MODE_SLOWHELL,
 	MODE_HELLX5,
 	MODE_HELLX9,
-	MODE_FSKHELL,
+	MODE_FSKH245,
 	MODE_FSKH105,
 	MODE_HELL80,
 	MODE_HELL_FIRST = MODE_FELDHELL,
